@@ -36,18 +36,23 @@
 #  include <gssapi/gssapi_ntlmssp.h>
 #endif
 
+#include <ctype.h>
+#include <pwd.h>
+#include <grp.h>
+
 #include "crypto.h"
 #include "sessions.h"
 #include "environ.h"
 
 #define MIN_SESS_EXP_TIME 300 /* 5 minutes validity minimum */
 
-#ifdef HAVE_GSS_ACQUIRE_CRED_FROM
-#  ifdef HAVE_GSS_STORE_CRED_INTO
-#define HAVE_CRED_STORE 1
-#  endif
+#if defined(HAVE_GSS_ACQUIRE_CRED_FROM) && defined(HAVE_GSS_STORE_CRED_INTO)
+#  define HAVE_CRED_STORE 1
 #endif
 
+extern module AP_MODULE_DECLARE_DATA auth_gssapi_module;
+#define GSS_NAME_ATTR_USERDATA "GSS Name Attributes Userdata"
+
 struct mag_na_map {
     char *env_name;
     char *attr_name;
@@ -69,9 +74,13 @@ struct mag_config {
 #ifdef HAVE_CRED_STORE
     bool use_s4u2proxy;
     char *deleg_ccache_dir;
+    mode_t deleg_ccache_mode;
+    uid_t deleg_ccache_uid;
+    gid_t deleg_ccache_gid;
     gss_key_value_set_desc *cred_store;
-    bool deleg_ccache_unique;;
+    bool deleg_ccache_unique;
     bool s4u2self;
+    char *ccname_envvar;
 #endif
     struct seal_key *mag_skey;
 
@@ -80,6 +89,10 @@ struct mag_config {
     gss_OID_set_desc *basic_mechs;
     bool negotiate_once;
     struct mag_name_attributes *name_attributes;
+    const char *required_na_expr;
+    bool enverrs;
+    gss_name_t acceptor_name;
+    bool acceptor_name_from_req;
 };
 
 struct mag_server_config {
@@ -115,12 +128,17 @@ struct mag_conn {
     struct databuf basic_hash;
     bool is_preserved;
     int na_count;
+    const char **required_name_attrs;
+    const char **required_name_vals;
     struct mag_attr *name_attributes;
     const char *ccname;
+    apr_table_t *env;
 };
 
 #define discard_const(ptr) ((void *)((uintptr_t)(ptr)))
 
 struct mag_conn *mag_new_conn_ctx(apr_pool_t *pool);
 const char *mag_str_auth_type(int auth_type);
-char *mag_error(request_rec *req, const char *msg, uint32_t maj, uint32_t min);
+char *mag_error(apr_pool_t *pool, const char *msg, uint32_t maj, uint32_t min);
+int mag_get_user_uid(const char *name, uid_t *uid);
+int mag_get_group_gid(const char *name, gid_t *gid);
